==> ejc-probid-api-3.0.0-20220722.081138-40-sources.jar: com/ejianc/business/bid/vo/RegisDataVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 报名资料
 * 
 * @author generator
 * 
 */
public class RegisDataVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long projectId; // 招标项目Id
    private String projectName; // 招标项目名称（带入）
    private String projectCode; // 招标项目编号
    private String constructionUnit; // 建设单位
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date registrationDeadline; // 报名截止日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date openingDate; // 开标日期
    private Long bidUnitId; // 投标单位
    private String bidUnitName; // 投标单位 名称
    private String bidUnitCode; // 投标单位 编码
    private String dataBuyType; // 资料购买类型 0:购买资格预审文件、1:购买招标文件、2:其他
    private String dataBuyTypeStr; // 资料购买类型 0:购买资格预审文件、1:购买招标文件、2:其他

    private String transactInformationId; // 办理资料
    private String transactInformationName; // 办理资料 名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date theDate; // 办理日期
    private String employeeCode; // 经办人编码
    private String employeeName; // 经办人名称
    private Long employeeId; // 经办人
    private Date commitData; // 提交日期
    private Integer billState; // 单据状态 ：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private String billCode; // 编码
    private Date commitDate; // 提交日期
    private Date effectiveDate; // 生效日期
    private String commitUserCode; // 提交人账号
    private String commitUserName; // 提交人名字
    private String memo; // 备注
    private String billStateName; // 单据状态名称

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
    public String getDataBuyTypeStr() {
        return dataBuyTypeStr;
    }

    public void setDataBuyTypeStr(String dataBuyTypeStr) {
        this.dataBuyTypeStr = dataBuyTypeStr;
    }

    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getConstructionUnit() {
        return constructionUnit;
    }

    public void setConstructionUnit(String constructionUnit) {
        this.constructionUnit = constructionUnit;
    }
    public Date getRegistrationDeadline() {
        return registrationDeadline;
    }

    public void setRegistrationDeadline(Date registrationDeadline) {
        this.registrationDeadline = registrationDeadline;
    }
    public Date getOpeningDate() {
        return openingDate;
    }

    public void setOpeningDate(Date openingDate) {
        this.openingDate = openingDate;
    }
    public Long getBidUnitId() {
        return bidUnitId;
    }

    public void setBidUnitId(Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    public String getBidUnitName() {
        return bidUnitName;
    }

    public void setBidUnitName(String bidUnitName) {
        this.bidUnitName = bidUnitName;
    }
    public String getBidUnitCode() {
        return bidUnitCode;
    }

    public void setBidUnitCode(String bidUnitCode) {
        this.bidUnitCode = bidUnitCode;
    }
    public String getDataBuyType() {
        return dataBuyType;
    }

    public void setDataBuyType(String dataBuyType) {
        this.dataBuyType = dataBuyType;
    }
    public String getTransactInformationId() {
        return transactInformationId;
    }

    public void setTransactInformationId(String transactInformationId) {
        this.transactInformationId = transactInformationId;
    }
    public String getTransactInformationName() {
        return transactInformationName;
    }

    public void setTransactInformationName(String transactInformationName) {
        this.transactInformationName = transactInformationName;
    }
    public Date getTheDate() {
        return theDate;
    }

    public void setTheDate(Date theDate) {
        this.theDate = theDate;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public Date getCommitData() {
        return commitData;
    }

    public void setCommitData(Date commitData) {
        this.commitData = commitData;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-probid-api-3.0.0-20220825.101202-78-sources.jar: com/ejianc/business/bid/vo/RegisDataVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 报名资料
 * 
 * @author generator
 * 
 */
public class RegisDataVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long projectId; // 招标项目Id
    private String projectName; // 招标项目名称（带入）
    private String projectCode; // 招标项目编号
    private String constructionUnit; // 建设单位
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date registrationDeadline; // 报名截止日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date openingDate; // 开标日期
    private Long bidUnitId; // 投标单位
    private String bidUnitName; // 投标单位 名称
    private String bidUnitCode; // 投标单位 编码
    private String dataBuyType; // 资料购买类型 0:购买资格预审文件、1:购买招标文件、2:其他
    private String dataBuyTypeStr; // 资料购买类型 0:购买资格预审文件、1:购买招标文件、2:其他

    private String transactInformationId; // 办理资料
    private String transactInformationName; // 办理资料 名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date theDate; // 办理日期
    private String employeeCode; // 经办人编码
    private String employeeName; // 经办人名称
    private Long employeeId; // 经办人
    private Date commitData; // 提交日期
    private Integer billState; // 单据状态 ：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private String billCode; // 编码
    private Date commitDate; // 提交日期
    private Date effectiveDate; // 生效日期
    private String commitUserCode; // 提交人账号
    private String commitUserName; // 提交人名字
    private String memo; // 备注
    private String billStateName; // 单据状态名称
    private String createTimeStr;
    private String theDateStr;

    public String getCreateTimeStr() {
        return createTimeStr;
    }

    public void setCreateTimeStr(String createTimeStr) {
        this.createTimeStr = createTimeStr;
    }

    public String getTheDateStr() {
        return theDateStr;
    }

    public void setTheDateStr(String theDateStr) {
        this.theDateStr = theDateStr;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
    public String getDataBuyTypeStr() {
        return dataBuyTypeStr;
    }

    public void setDataBuyTypeStr(String dataBuyTypeStr) {
        this.dataBuyTypeStr = dataBuyTypeStr;
    }

    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getConstructionUnit() {
        return constructionUnit;
    }

    public void setConstructionUnit(String constructionUnit) {
        this.constructionUnit = constructionUnit;
    }
    public Date getRegistrationDeadline() {
        return registrationDeadline;
    }

    public void setRegistrationDeadline(Date registrationDeadline) {
        this.registrationDeadline = registrationDeadline;
    }
    public Date getOpeningDate() {
        return openingDate;
    }

    public void setOpeningDate(Date openingDate) {
        this.openingDate = openingDate;
    }
    public Long getBidUnitId() {
        return bidUnitId;
    }

    public void setBidUnitId(Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    public String getBidUnitName() {
        return bidUnitName;
    }

    public void setBidUnitName(String bidUnitName) {
        this.bidUnitName = bidUnitName;
    }
    public String getBidUnitCode() {
        return bidUnitCode;
    }

    public void setBidUnitCode(String bidUnitCode) {
        this.bidUnitCode = bidUnitCode;
    }
    public String getDataBuyType() {
        return dataBuyType;
    }

    public void setDataBuyType(String dataBuyType) {
        this.dataBuyType = dataBuyType;
    }
    public String getTransactInformationId() {
        return transactInformationId;
    }

    public void setTransactInformationId(String transactInformationId) {
        this.transactInformationId = transactInformationId;
    }
    public String getTransactInformationName() {
        return transactInformationName;
    }

    public void setTransactInformationName(String transactInformationName) {
        this.transactInformationName = transactInformationName;
    }
    public Date getTheDate() {
        return theDate;
    }

    public void setTheDate(Date theDate) {
        this.theDate = theDate;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public Date getCommitData() {
        return commitData;
    }

    public void setCommitData(Date commitData) {
        this.commitData = commitData;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
